@@ -1,8 +1,10 @@
+from blogtool import __version__
+
 from headerparse import HeaderError
 from xmlproxy.proxybase import ProxyError
 from fileprocessor import FileProcessor, FileProcessorError
 
-from optparse import OptionParser
+import argparse
 
 import html2md
 import utils
@@ -370,7 +372,7 @@ updating with blogtool.
         header_str += 'CATEGORIES: %s\n' % self._buildCatStr(post['categories'])
         if post['mt_keywords']:
             header_str += 'TAGS: %s\n' % post['mt_keywords']
-        print header_str + '\n' + text
+        print (header_str + '\n' + text).encode("utf8")
         return None
 
     def _buildCatStr(self, catlist):
@@ -747,13 +749,18 @@ class SetPostComment(CommandLineOption):
               'action' : 'store',
               'dest' : 'comment',
               'default' : False,
-              'metavar' : 'POSTID',
-              'help' : "Post text from file as a comment to post POSTID."
+              'metavar' : ('POSTID', 'COMMENTID'),
+              'nargs' : 2,
+              'help' : """
+Post text from file as a comment to post POSTID.  If the comment is in answer to
+another comment, supply the COMMENTID, otherwise set it to 0.
+"""
              }
 
     def check(self, opts):
         if opts.comment:
-            self.postid = opts.comment
+            self.postid = opts.comment[0]
+            self.parentid = opts.comment[1]
             opts.comment = True  # used by the headerparse module
             return True
         else:
@@ -761,6 +768,7 @@ class SetPostComment(CommandLineOption):
 
     def run(self, header, opts):
         header.postid = self.postid
+        header.parentid = self.parentid
         return 'runeditor'
 
 ################################################################################
@@ -790,6 +798,25 @@ markdown.
         header.charset = self.charset
         return 'runeditor' 
 
+################################################################################
+'''
+    GetVersion
+'''
+class GetVersion(CommandLineOption):
+    args = ('--version',)
+    kwargs = {
+              'action' : 'store_true',
+              'dest' : 'version',
+             }
+
+    def check(self, opts):
+        return opts.version
+
+    def run(self, header, opts):
+        print "blogtool version  %s" % __version__
+        return None
+
+
 ################################################################################
 '''
     OptionProcessor
@@ -814,14 +841,16 @@ class OptionProcessor:
         self.o_list.append(UploadMediaFile())
         self.o_list.append(GetComments())
         self.o_list.append(EditComment())
+        self.o_list.append(GetVersion())
 
-        self.parser = OptionParser("Usage: %prog [option] postfile1 postfile2 ...")
+        self.parser = argparse.ArgumentParser(description = "Command line based blog client")
         for option in self.o_list:
-            self.parser.add_option(*option.args, **option.kwargs)
+            self.parser.add_argument(*option.args, **option.kwargs)
+        self.parser.add_argument('postfile', nargs='*', help= "File or files to post to a blog")
 
     def parse(self):
-        self.opts, files = self.parser.parse_args()
-        return files
+        self.opts = self.parser.parse_args()
+        return self.opts.postfile
 
     def flags(self):
         return {
@@ -841,4 +870,3 @@ class OptionProcessor:
                      rval = True
 
         return rval
-
